#ifndef HALKEYBOARDS_H
#define HALKEYBOARDS_H

#include <QMap>
#include <QWidget>

class HalKeyboards:public QMap< QString,QString >
{
public:
    HalKeyboards(QWidget * parent);
};

#endif // HALKEYBOARDS_H
